@@ -12,10 +12,18 @@ analyze_failure --force-analysis noexpr.vhdl
 analyze_failure --force-analysis str.vhdl
 analyze_failure --force-analysis procinter.vhdl
 analyze_failure --force-analysis emptyquote2.vhdl
+analyze_failure --force-analysis bitstr.vhdl
 analyze_failure usrattr.vhdl
 analyze_failure forloop.vhdl 
 analyze_failure emptyquote.vhdl
 analyze_failure qual.vhdl
+analyze_failure proctarg.vhdl
+analyze_failure libparen.vhdl
+analyze_failure --force-analysis badrng.vhdl
+analyze_failure --force-analysis attr.vhdl
+analyze_failure --force-analysis attr2.vhdl
+analyze_failure paren.vhdl
+analyze_failure --force-analysis attr3.vhdl
 
 if analyze_failure --force-analysis notype1.vhdl 2>&1 | grep -q "indexed name"; then
   :
